using System;
using System.Linq;
using System.Collections.Generic;


class Solution {

    private static List<Vector2> buffer = new();
    private static List<Rect> obstacles = new();
    private static Vector2 limit = new();

  public static void Main(string[] args) {
    int[] values = Console.ReadLine().Split(" ").Select(n => int.Parse(n)).ToArray();
    Vector2 roomSize = new (values[0], values[1]);
    int rectCount = values[2];

    List<Rect> rects = new();

    for(int i = 0; i < rectCount; i++)
    {
        var r = Console.ReadLine().Split(" ").Select(n => int.Parse(n)).ToList();
        rects.Add(new Rect(new Vector2(r[0], r[1]), new Vector2(r[2], r[3])));
    }

    var origin = new Vector2(0, 0);
    var result = CanReach(roomSize, origin, rects) ? "YES" : "NO"; 
    Console.WriteLine(result);
  }

  public static bool CanReach(Vector2 origin, Vector2 dest, List<Rect> obst)
  {
    buffer = new();
    obstacles = obst;
    buffer.Add(origin);
    limit = origin;
    FillBuffer(obst);
    return ReachIteration(origin, dest);
  }

  public static void FillBuffer(List<Rect> obstacles)
  {
    foreach(var o in obstacles)
    {
      for(double x = o.TopLeft.x; x <= o.BottomRight.x; x+=0.5)
      {
        buffer.Add(new Vector2(x, o.TopLeft.y));
        buffer.Add(new Vector2(x, o.BottomRight.y));
      }
      
      for(double y = o.TopLeft.y; y <= o.BottomRight.y; y+=0.5)
      {
        buffer.Add(new Vector2(o.TopLeft.x, y));
        buffer.Add(new Vector2(o.BottomRight.x, y));
      }
    }
  }

  private static bool ReachIteration(Vector2 current, Vector2 dest)
  {
    List<Vector2> open = new List<Vector2>();
    open.Add(current);

    while(current != dest && open.Count != 0)
    {

      current = open[0];
      Console.WriteLine($"{current.x} {current.y}");
      buffer.Add(current);
      open.RemoveAll(c => c == current);

        var nb = GetNeigbours(current).Where(n => IsValid(n) && !buffer.Contains(n) && !open.Contains(n)).ToList();
      //buffer.AddRange(nb);
      //nb = nb

      open.AddRange(nb);
      open = open.OrderBy(n => {
        var dx = Math.Abs(n.x - dest.x);
        var dy = Math.Abs(n.y - dest.y);
        return Math.Sqrt(dx*dx+dy*dy);
      }).ToList();

      // foreach(var n in nb)
      // {
      //     if(n == dest) return true;
      //     //if(!IsValid(n, dest)) continue;
      //     //if(buffer.Contains(n)) continue;
      //     //if(obstacles.Any(o => IsWithinRectangle(n, o))) continue;
          
      //     if(ReachIteration(n, dest)) return true;
      // }
    }

    return (current == dest);
  }

  private static bool IsWithinRectangle(Vector2 point, Rect r)
  {
    return point.x >= r.TopLeft.x && point.x <= r.BottomRight.x &&
           point.y >= r.TopLeft.y && point.y <= r.BottomRight.y;
  }

  private static bool IsValid(Vector2 point)
  {
    return IsWithinRectangle(point, new Rect(new Vector2(0, 0), limit));
  }

  public static List<Vector2> GetNeigbours(Vector2 p)
  {
    List<Vector2> l = new();
    double i = 0.5;
    l.Add(new (p.x + i, p.y));
    l.Add(new (p.x - i, p.y));
    l.Add(new (p.x, p.y + i));
    l.Add(new (p.x, p.y - i));
    return l;
  }

  public struct Vector2
  {
    public double x;
    public double y;

    public Vector2(double x, double y)
    {
        this.x = x;
        this.y = y;
    }

    public static bool operator ==(Vector2 a, Vector2 b)
    {
        return a.x == b.x && a.y == b.y;
    }

    public static bool operator !=(Vector2 a, Vector2 b)
    {
        return !(a == b);
    }

    public override bool Equals(object? o)
    {
        if(o is not Vector2 v) return false;
        return this == v;
    }

    public override int GetHashCode()
    {
        return (int)(x * 2 + y * 20);
    }
  }

  public struct Rect
  {
    public Vector2 TopLeft;
    public Vector2 BottomRight;

    public Rect(Vector2 tl, Vector2 br)
    {
        TopLeft = tl;
        BottomRight = br;
    }
  }
}
