using System;
using System.Linq;
using System.Collections.Generic;


class Solution {
  public static void Main(string[] args) {
    int[] values = Console.ReadLine().Split(" ").Select(n => int.Parse(n)).ToArray();
    Vector2 roomSize = new (values[0], values[1]);
    int rectCount = values[2];

    Rect room = new (new(0, 0), roomSize);

    List<Rect> rects = new();

    for(int i = 0; i < rectCount; i++)
    {
      var r = Console.ReadLine().Split(" ").Select(n => int.Parse(n)).ToList();
      rects.Add(new Rect(new Vector2(r[0], r[1]), new Vector2(r[2], r[3])));
    }

    List<RectList> list = new();
    List<Rect> current = new();
    int index = -1;
    while(rects.Count != 0)
    {
      if(current.Count == 0)
      {
        index++;
        current.Add(rects.First());
        rects.Remove(current.Single());

        list.Add(new());
        list[index].rects.AddRange(current);
      }

      List<Rect> next = new();
      foreach(var rect in current)
      {
        var touching = rects.Where(r => DoOverlap(rect, r)).ToList();
        //Console.WriteLine(touching.Count);
        rects.RemoveAll(r => touching.Contains(r));
        next.AddRange(touching);
      }

      list[index].rects.AddRange(next);
      current = next;
    }

    foreach(var l in list)
    {
      foreach(var r in l.rects)
      {
        l.bt = l.bt.Merge(TouchesBordersAt(r, room));
      }
    }

    var blocksExit = list.Any(l => DoesBlockExit(l.bt));
    var result = blocksExit ? "NO" : "YES";
    Console.WriteLine(result);

    //Console.WriteLine(string.Join(" ", list.Select(l => DoesBlockExit(l.bt))));
  }

  public class RectList
  {
    public BordersTouch bt;
    public List<Rect> rects = new();
  }

  public static bool DoesBlockExit(BordersTouch bt)
  {
    if(bt.TopBorder && bt.LeftBorder) return true;
    if(bt.TopBorder && bt.BottomBorder) return true;

    if(bt.RightBorder && bt.BottomBorder) return true;
    if(bt.RightBorder && bt.LeftBorder) return true;

    return false;
  }

  public static BordersTouch TouchesBordersAt(Rect r, Rect borders)
  {
    BordersTouch touch = new();
    
    if(r.TopLeft.x <= borders.TopLeft.x && r.BottomRight.x >= borders.TopLeft.x)
    {
      touch.LeftBorder = true;
    }

    if(r.TopLeft.x <= borders.BottomRight.x && r.BottomRight.x >= borders.BottomRight.x)
    {
      touch.RightBorder = true;
    }

    if(r.TopLeft.y <= borders.TopLeft.y && r.BottomRight.y >= borders.TopLeft.y)
    {
      touch.TopBorder = true;
    }
    
    if(r.TopLeft.y <= borders.BottomRight.y && r.BottomRight.y >= borders.BottomRight.y)
    {
      touch.BottomBorder = true;
    }

    return touch;
  }

  public static bool DoOverlap(Rect a, Rect b)
  {
    // if (a.TopLeft.x == a.BottomRight.x || a.TopLeft.y == a.BottomRight.y || b.BottomRight.x == b.TopLeft.x || b.TopLeft.y == b.BottomRight.y)
    //     return false;
   
    if (a.TopLeft.x > b.BottomRight.x || b.TopLeft.x > a.BottomRight.x)
        return false;
 
    if (a.BottomRight.y < b.TopLeft.y || b.BottomRight.y < a.TopLeft.y)
        return false;
 
    return true;
  }

  public struct BordersTouch
  {
    public bool TopBorder;
    public bool BottomBorder;
    public bool LeftBorder;
    public bool RightBorder;

    public BordersTouch Merge(BordersTouch a)
    {
      var b = new BordersTouch();
      b.TopBorder = TopBorder || a.TopBorder;
      b.BottomBorder = BottomBorder || a.BottomBorder;
      b.LeftBorder = LeftBorder || a.LeftBorder;
      b.RightBorder = RightBorder || a.RightBorder;

      return b;
    }
  }

  public struct Vector2
  {
    public double x;
    public double y;

    public Vector2(double x, double y)
    {
        this.x = x;
        this.y = y;
    }

    public static bool operator ==(Vector2 a, Vector2 b)
    {
        return a.x == b.x && a.y == b.y;
    }

    public static bool operator !=(Vector2 a, Vector2 b)
    {
        return !(a == b);
    }

    public override bool Equals(object o)
    {
        if(o is not Vector2 v) return false;
        return this == v;
    }

    public override int GetHashCode()
    {
        return (int)(x * 2 + y * 20);
    }
  }

  public struct Rect
  {
    public Vector2 TopLeft;
    public Vector2 BottomRight;

    public Rect(Vector2 tl, Vector2 br)
    {
        TopLeft = tl;
        BottomRight = br;
    }

    public static bool operator ==(Rect a, Rect b)
    {
        return a.TopLeft == b.TopLeft && a.BottomRight == b.BottomRight;
    }

    public static bool operator !=(Rect a, Rect b)
    {
        return !(a == b);
    }

    public override bool Equals(object o)
    {
        if(o is not Rect v) return false;
        return this == v;
    }

    public override int GetHashCode()
    {
        return 15;
    }
  }

  
}
