#include <bits/stdc++.h>
#include <ext/pb_ds/assoc_container.hpp>

using namespace std;
using namespace __gnu_pbds;
using ll = long long;

struct Fenwick {
    vector<ll> fen;
    vector<ll> arr;

    Fenwick(vector<ll>& a) {
        ll n = a.size();
        fen.assign(n + 1, 0);
        arr.assign(n + 1, 0);

        int i = 1;
        while (i <= n) {
            arr[i] = a[i - 1];
            fen[i] += arr[i];

            int j = i + (i & (-i));
            if (j <= n) {
                fen[j] += fen[i];
            }
        }
    }

    ll getSum(ll r) {
        int j = r;
        ll res = 0;
        while (j > 0) {
            res += fen[j];
            j -= (j & (-j));
        }
        return res;
    }

    ll query(ll l, ll r) {
        return getSum(r) - getSum(l - 1);
    }

    void update(ll i, ll val) {
        int j = i;
        while (j < fen.size()) {
            fen[j] -= arr[i];
            fen[j] += val;
            j += (j & (-j));
        }
        arr[i] = val;
    }
};

struct Segment {
    vector<ll> seg;
    vector<ll> lazy;

    Segment(vector<ll>& arr) {
        ll n = arr.size();
        seg.assign(4 * n, 0);
        lazy.assign(4 * n, 0);
        build(0, 0, n - 1, arr);
    }

    void build(ll ind, ll low, ll high, vector<ll>& arr) {
        if (low == high) {
            seg[ind] = arr[low];
        }
        else {
            int mid = (low + high) / 2;
            build(ind * 2 + 1, low, mid, arr);
            build(ind * 2 + 2, mid + 1, high, arr);
        }
    }

    ll query(ll ind, ll l, ll r, ll low, ll high) {
        if (lazy[ind] != 0) {
            seg[ind] += lazy[ind];
            if (low != high) {
                lazy[ind * 2 + 1] += lazy[ind];
                lazy[ind * 2 + 2] += lazy[ind];
            }
            lazy[ind] = 0;
        }
        if (high < l || low > r || high < low) return LLONG_MAX;
        else if (high <= r && low >= l) return seg[ind];
        else {
            int mid = (low + high) / 2;
            return min(query(ind * 2 + 1, l, r, low, mid), query(ind * 2 + 2, l, r, mid + 1, high));
        }
    }

    void update(ll ind, ll l, ll r) {

    }
};


ll n;
const int N = 1e6;
bool visited[N + 1];

void dfs(ll node) {
    visited[node] = true;
    ll next = node * 2;
    if (next > n) next -= n;
    if (!visited[next]) {
        dfs(next);
    }
    if (node % 2 == 0 && !visited[node / 2]) {
        dfs(node / 2);
    }
    if ((node + n) % 2 == 0 && !visited[(node + n) / 2]) {
        dfs((node + n) / 2);
    }
}

int main() {
    ios_base::sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);

    cin >> n;
    visited[1] = true;
    dfs(1);
    ll bad = -1;
    for (int i = 2; i <= n; i++) {
        if (!visited[i]) {
            bad = i;
            break;
        }
    }
    if (bad == -1) {
        printf("YES\n");
    }
    else {
        printf("NO\n");
        printf("1 %lld\n", bad);
    }
}