#include <bits/stdc++.h>
#include <ext/pb_ds/assoc_container.hpp>

using namespace std;
using namespace __gnu_pbds;
using ll = long long;

struct Fenwick {
    vector<ll> fen;
    vector<ll> arr;

    Fenwick(vector<ll>& a) {
        ll n = a.size();
        fen.assign(n + 1, 0);
        arr.assign(n + 1, 0);

        int i = 1;
        while (i <= n) {
            arr[i] = a[i - 1];
            fen[i] += arr[i];

            int j = i + (i & (-i));
            if (j <= n) {
                fen[j] += fen[i];
            }
        }
    }

    ll getSum(ll r) {
        int j = r;
        ll res = 0;
        while (j > 0) {
            res += fen[j];
            j -= (j & (-j));
        }
        return res;
    }

    ll query(ll l, ll r) {
        return getSum(r) - getSum(l - 1);
    }

    void update(ll i, ll val) {
        int j = i;
        while (j < fen.size()) {
            fen[j] -= arr[i];
            fen[j] += val;
            j += (j & (-j));
        }
        arr[i] = val;
    }
};

struct Segment {
    vector<ll> seg;
    vector<ll> lazy;

    Segment(vector<ll>& arr) {
        ll n = arr.size();
        seg.assign(4 * n, 0);
        lazy.assign(4 * n, 0);
        build(0, 0, n - 1, arr);
    }

    void build(ll ind, ll low, ll high, vector<ll>& arr) {
        if (low == high) {
            seg[ind] = arr[low];
        }
        else {
            int mid = (low + high) / 2;
            build(ind * 2 + 1, low, mid, arr);
            build(ind * 2 + 2, mid + 1, high, arr);
        }
    }

    ll query(ll ind, ll l, ll r, ll low, ll high) {
        if (lazy[ind] != 0) {
            seg[ind] += lazy[ind];
            if (low != high) {
                lazy[ind * 2 + 1] += lazy[ind];
                lazy[ind * 2 + 2] += lazy[ind];
            }
            lazy[ind] = 0;
        }
        if (high < l || low > r || high < low) return LLONG_MAX;
        else if (high <= r && low >= l) return seg[ind];
        else {
            int mid = (low + high) / 2;
            return min(query(ind * 2 + 1, l, r, low, mid), query(ind * 2 + 2, l, r, mid + 1, high));
        }
    }

    void update(ll ind, ll l, ll r) {

    }
};

struct Sparse {
    vector<vector<ll>> sp;

    Sparse() {

    }

    Sparse(vector<ll>& arr) {
        ll n = arr.size();
        sp.assign(n, vector<ll>(log2(n) + 1, 0));

        for (int i = 0; i < n; i++) sp[i][0] = arr[i];

        for (int p = 1; p <= log2(n); p++) {
            for (int i = 0; i <= n - (1 << p); i++) {
                sp[i][p] = min(sp[i][p - 1], sp[i + (1 << (p - 1))][p - 1]);
            }
        }
    }

    ll query(ll l, ll r) {
        if (r < l) return LLONG_MAX;
        ll p = log2(r - l + 1);
        return min(sp[l][p], sp[r - (1 << p) + 1][p]);
    }
};

ll n;
const int N = 1e6;
vector<ll> a;
Sparse sp;

ll rsearch(ll i, ll val) { // index
    ll begin = i + 1;
    ll end = n - 1;

    while (begin <= end) {
        ll mid = (begin + end) / 2;
        if (sp.query(i + 1, mid) < val) {
            end = mid - 1;
        }
        else {
            begin = mid + 1;    
        }
    }

    return end + 1;
}

ll lsearch(ll i, ll val) {
    ll begin = 0;
    ll end = i - 1;

    while (begin <= end) {
        ll mid = (begin + end) / 2;
        if (sp.query(mid, i - 1) < val) {
            begin = mid + 1;
        }
        else {
            end = mid - 1;
        }
    }
    return begin - 1;
}

ll calc(ll i) {
    ll lfirst = lsearch(i, a[i]);
    ll lsecond = -1;
    if (lfirst != -1) {
         lsecond = lsearch(lfirst, a[i]);
    }

    ll rfirst = rsearch(i, a[i]);
    ll rsecond = n;
    if (rfirst != n) {
        rsecond = rsearch(rfirst, a[i]);
    }

    ll secondMin = min(sp.query(lfirst + 1, i - 1), sp.query(i + 1, rfirst - 1));

    ll res = LLONG_MIN;
    if (secondMin != LLONG_MAX) {
        res = (a[i] + secondMin) * (rfirst - lfirst - 1);
    }
    if (lfirst != -1) {
        res = max(res, (a[i] + a[lfirst]) * (rfirst - lsecond - 1));
    }
    if (rfirst != n) {
        res = max(res, (a[i] + a[rfirst]) * (rsecond - lfirst - 1));
    }
    return res;
}

int main() {
    ios_base::sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);

    cin >> n;
    a.assign(n, 0);
    for (int i = 0; i < n; i++) cin >> a[i];

    sp = Sparse(a);
    
    ll res = LLONG_MIN;
    for (int i = 0; i < n; i++) {
        res = max(res, calc(i));
    }

    printf("%lld\n", res);
}